diff --git a/documentation/users-guide/PhysicsVectors.md b/documentation/users-guide/PhysicsVectors.md
index d3b4bae8a226e012b069f64acc136f16bc9aac07..0d5187346a1ed418162861b0212e302e89fd6fb7 100644
--- a/documentation/users-guide/PhysicsVectors.md
+++ b/documentation/users-guide/PhysicsVectors.md
@@ -5,7 +5,7 @@ The physics vector classes describe vectors in three and four dimensions
 and their rotation algorithms. The classes were ported to root from
 CLHEP see:
 
-<http://wwwinfo.cern.ch/asd/lhc++/clhep/manual/UserGuide/Vector/vector.html>
+<http://www.cern.ch/clhep/manual/UserGuide/Vector/vector.html>
 
 ## The Physics Vector Classes
 
diff --git a/hist/hist/src/TVirtualFitter.cxx b/hist/hist/src/TVirtualFitter.cxx
index 3885cefe751cf7a40c0e1e0d9024105297f70618..e914951894c8de90b5c240cfbb697430db20391c 100644
--- a/hist/hist/src/TVirtualFitter.cxx
+++ b/hist/hist/src/TVirtualFitter.cxx
@@ -331,7 +331,7 @@ void TVirtualFitter::SetFCN(void *fcn)
 ////////////////////////////////////////////////////////////////////////////////
 /// static: Set the maximum number of function calls for the minimization algorithm
 /// For example for MIGRAD this is the maxcalls value passed as first argument
-/// (see http://wwwasdoc.web.cern.ch/wwwasdoc/minuit/node18.html )
+/// (see https://cern-tex.web.cern.ch/cern-tex/minuit/node18.html )
 
 void TVirtualFitter::SetMaxIterations(Int_t niter)
 {
@@ -341,7 +341,7 @@ void TVirtualFitter::SetMaxIterations(Int_t niter)
 ////////////////////////////////////////////////////////////////////////////////
 /// static: Set the Error Definition (default=1)
 /// For Minuit this is the value passed with the "SET ERR" command
-/// (see http://wwwasdoc.web.cern.ch/wwwasdoc/minuit/node18.html)
+/// (see https://cern-tex.web.cern.ch/cern-tex/minuit/node18.html)
 
 void TVirtualFitter::SetErrorDef(Double_t errdef)
 {
@@ -356,7 +356,7 @@ void TVirtualFitter::SetErrorDef(Double_t errdef)
 ////////////////////////////////////////////////////////////////////////////////
 /// static: Set the tolerance used in the minimization algorithm
 /// For example for MIGRAD this is tolerance value passed as second argument
-/// (see http://wwwasdoc.web.cern.ch/wwwasdoc/minuit/node18.html )
+/// (see https://cern-tex.web.cern.ch/cern-tex/minuit/node18.html )
 
 void TVirtualFitter::SetPrecision(Double_t prec)
 {
diff --git a/man/man1/g2root.1 b/man/man1/g2root.1
index 16c81999b5196e1dd924fdf5cabb9966959b5c3b..3e80621130b696c7317d767fa989571e12bf24af 100644
--- a/man/man1/g2root.1
+++ b/man/man1/g2root.1
@@ -13,7 +13,7 @@ g2root \- convert GEANT geometry files to ROOT files
 You can convert a
 .B GEANT
 (see
-.I http://wwwinfo.cern.ch/asd/geant/index.html
+.I http://geant.cern.ch/
 fore more on
 .BR GEANT )
 geometry to
@@ -54,7 +54,7 @@ session;
 .nf
 root [1] .x detector.C
 root [2] detector.Draw()
-root [3] c1.x3d()   // (this invokes the 3-d Root viewver)
+root [3] c1.x3d()   // (this invokes the 3-d Root viewer)
 root [4] TFile f("detector.root","NEW") //open a new root file
 root [5] detector.Write() //Write the geometry structure
 root [6] f.Write()
diff --git a/man/man1/g2rootold.1 b/man/man1/g2rootold.1
index a8cf1fbd550f6c84aaace6778ca12d22c3f51421..45b038f83d90b937e9f890a94442a84a996c1355 100644
--- a/man/man1/g2rootold.1
+++ b/man/man1/g2rootold.1
@@ -5,7 +5,7 @@
 .\" NAME should be all caps, SECTION should be 1-8, maybe w/ subsection
 .\" other parms are allowed: see man(7), man(1)
 .SH NAME
-g2rootold \- convert GEANT geomtry files to ROOT files
+g2rootold \- convert GEANT geometry files to ROOT files
 .SH SYNOPSIS
 .B g2rootoldd
 .I [-f map_name] geant_name macro_name
@@ -13,7 +13,7 @@ g2rootold \- convert GEANT geomtry files to ROOT files
 You can convert a
 .B GEANT
 (see
-.I http://wwwinfo.cern.ch/asd/geant/index.html
+.I http://geant.cern.ch/
 fore more on
 .BR GEANT )
 geometry to
@@ -54,7 +54,7 @@ session;
 .nf
 root [1] .x detector.C
 root [2] detector.Draw()
-root [3] c1.x3d()   // (this invokes the 3-d Root viewver)
+root [3] c1.x3d()   // (this invokes the 3-d Root viewer)
 root [4] TFile f("detector.root","NEW") //open a new root file
 root [5] detector.Write() //Write the geometry structure
 root [6] f.Write()
@@ -103,9 +103,9 @@ and
 .I JDIGI.
 .SH "SEE ALSO"
 .RS
-.IR root (1),
-.IR g2root (1),
-.IR h2root(1),
+.IR root(1) ,
+.IR g2root(1) ,
+.IR h2root(1) ,
 .RE
 and
 .RS
diff --git a/math/doc/v520/index.html b/math/doc/v520/index.html
index 3a5043cd2bbaf96736ddd22cc6e5f3e74ac66dd5..e64ae1df4b0dce810e30fee7cbc7ee043415a130 100644
--- a/math/doc/v520/index.html
+++ b/math/doc/v520/index.html
@@ -74,7 +74,7 @@ In detail, the new classes containing implementations present previously in <tt>
 
     <ul>
   <li><tt>GaussIntegrator</tt> and <tt>GaussLegendreIntegrator</tt> for numerical integration of one-dimensional functions. The first class uses Gaussian  8 and 16 point  quadrature approximation, it provides the translation of the CERNLIB algorithm
-  <a href="http://wwwasdoc.web.cern.ch/wwwasdoc/shortwrupsdir/d103/top.html">DGAUSS</a> by Sigfried Kolbig,  and it is used by the <tt>TF1::Integral</tt> method. The second one uses the Gauss Legendre quadrature formula. It is used by the <tt>TF1::IntegralFast</tt> method.
+  <a href="https://cern-tex.web.cern.ch/cern-tex/shortwrupsdir/d103/top.html">DGAUSS</a> by Sigfried Kolbig,  and it is used by the <tt>TF1::Integral</tt> method. The second one uses the Gauss Legendre quadrature formula. It is used by the <tt>TF1::IntegralFast</tt> method.
   These classes implement both the same  virtual interface as the adaptive integration methods provided by the MathMore library.  They can all be created and used easily via the common class <tt>ROOT::Math::IntegratorOneDim</tt> providing the interfaces for numerical integration.
 New template methods have been also included in the common Integration class in order to be able to integrate automatically any C++ callable object.
 </li>
diff --git a/math/mathcore/inc/Math/PdfFuncMathCore.h b/math/mathcore/inc/Math/PdfFuncMathCore.h
index 29326a24424bf2b9477b0677d6250ce1d7036075..7e504dd0d9535ae9fb33eeba5abc50f4acbb67b3 100644
--- a/math/mathcore/inc/Math/PdfFuncMathCore.h
+++ b/math/mathcore/inc/Math/PdfFuncMathCore.h
@@ -178,7 +178,7 @@ namespace Math {
 
   Crystal ball function
 
-  See the definition at 
+  See the definition at
   <A HREF="http://en.wikipedia.org/wiki/Crystal_Ball_function">
   Wikipedia</A>.
 
@@ -187,11 +187,11 @@ namespace Math {
   @ingroup PdfFunc
 
   */
-   
+
   double crystalball_function(double x, double alpha, double n, double sigma, double x0 = 0);
 
-   /** 
-       pdf definition of the crystal_ball which is defined only for n > 1 otehrwise integral is diverging
+   /**
+       pdf definition of the crystal_ball which is defined only for n > 1 otherwise integral is diverging
     */
   double crystalball_pdf(double x, double alpha, double n, double sigma, double x0 = 0);
 
@@ -275,13 +275,13 @@ namespace Math {
 
   Probability density function of the bi-dimensional (Gaussian) distribution.
 
-  \f[ p(x) = {1 \over 2 \pi \sigma_x \sigma_y \sqrt{1-\rho^2}} \exp (-(x^2/\sigma_x^2 + y^2/\sigma_y^2 - 2 \rho x y/(\sigma_x\sigma_y))/2(1-\rho^2)) \f]  
+  \f[ p(x) = {1 \over 2 \pi \sigma_x \sigma_y \sqrt{1-\rho^2}} \exp (-(x^2/\sigma_x^2 + y^2/\sigma_y^2 - 2 \rho x y/(\sigma_x\sigma_y))/2(1-\rho^2)) \f]
 
   For detailed description see
   <A HREF="http://mathworld.wolfram.com/BivariateNormalDistribution.html">
   Mathworld</A>. It can also be evaluated using #normal_pdf which will
   call the same implementation.
-  
+
  @param rho correlation , must be between -1,1
 
   @ingroup PdfFunc
@@ -301,7 +301,7 @@ namespace Math {
    <A HREF="http://dx.doi.org/10.1016/0010-4655(84)90085-7">Computer Phys. Comm. 31 (1984) 97-111</A>
    <A HREF="http://dx.doi.org/10.1016/j.cpc.2008.03.002">[Erratum-ibid. 178 (2008) 972]</A>.
    The same algorithms as in
-   <A HREF="http://wwwasdoc.web.cern.ch/wwwasdoc/shortwrupsdir/g110/top.html">
+   <A HREF="https://cern-tex.web.cern.ch/cern-tex/shortwrupsdir/g110/top.html">
    CERNLIB</A> (DENLAN)  is used
 
    @param x The argument \f$x\f$
@@ -326,7 +326,7 @@ namespace Math {
   <A HREF="http://mathworld.wolfram.com/LogNormalDistribution.html">
   Mathworld</A>.
   @param s scale parameter (not the sigma of the distribution which is not even defined)
-  @param x0  location parameter, corresponds approximatly to the most probable value. For x0 = 0, sigma = 1, the x_mpv = -0.22278
+  @param x0  location parameter, corresponds approximately to the most probable value. For x0 = 0, sigma = 1, the x_mpv = -0.22278
 
   @ingroup PdfFunc
 
diff --git a/math/mathcore/inc/Math/QuantFuncMathCore.h b/math/mathcore/inc/Math/QuantFuncMathCore.h
index b532cba416e5b63946bdb52cf58b72ec208accd1..89984fac1c9b12a6d154db54ada7a530852ef779 100644
--- a/math/mathcore/inc/Math/QuantFuncMathCore.h
+++ b/math/mathcore/inc/Math/QuantFuncMathCore.h
@@ -53,7 +53,7 @@ namespace Math {
    *  \f[ D(x) = \int_{x}^{+\infty} p(x') dx' \f]
    *
    *  These functions are defined in the header file <em>Math/ProbFunc.h<em> or in the global one
-   *  including all statistical dunctions <em>Math/DistFunc.h<em>
+   *  including all statistical functions <em>Math/DistFunc.h<em>
    *
    *
    * <strong>NOTE:</strong> In the old releases (< 5.14) the <em>_quantile</em> functions were called
@@ -209,7 +209,7 @@ namespace Math {
       <A HREF="http://mathworld.wolfram.com/Chi-SquaredDistribution.html">
       Mathworld</A>.
       It is implemented using  chisquared_quantile_c, therefore is not very precise for small z.
-      It is reccomended to use the MathMore function (ROOT::MathMore::chisquared_quantile )implemented using GSL
+      It is recommended to use the MathMore function (ROOT::MathMore::chisquared_quantile )implemented using GSL
 
       @ingroup QuantFunc
 
@@ -311,7 +311,7 @@ namespace Math {
       <A HREF="http://mathworld.wolfram.com/GammaDistribution.html">
       Mathworld</A>.
       It is implemented using  chisquared_quantile_c, therefore is not very precise for small z.
-      For this special cases it is reccomended to use the MathMore function ROOT::MathMore::gamma_quantile
+      For this special cases it is recommended to use the MathMore function ROOT::MathMore::gamma_quantile
       implemented using GSL
 
 
@@ -528,7 +528,7 @@ namespace Math {
    <A HREF="http://dx.doi.org/10.1016/0010-4655(84)90085-7">Computer Phys. Comm. 31 (1984) 97-111</A>
    <A HREF="http://dx.doi.org/10.1016/j.cpc.2008.03.002">[Erratum-ibid. 178 (2008) 972]</A>.
    The same algorithms as in
-   <A HREF="http://wwwasdoc.web.cern.ch/wwwasdoc/shortwrupsdir/g110/top.html">
+   <A HREF="https://cern-tex.web.cern.ch/cern-tex/shortwrupsdir/g110/top.html">
    CERNLIB</A> (RANLAN) is used.
 
    @param z The argument \f$z\f$
diff --git a/math/mathcore/inc/Math/SpecFuncMathCore.h b/math/mathcore/inc/Math/SpecFuncMathCore.h
index 418da1ed56c0b09d5ad232fd5a1d62f7affa66c4..612534437501f0e02cd9abdc2fe67b01d7b3a55f 100644
--- a/math/mathcore/inc/Math/SpecFuncMathCore.h
+++ b/math/mathcore/inc/Math/SpecFuncMathCore.h
@@ -193,7 +193,7 @@ namespace Math {
   For detailed description see
   <A HREF="http://mathworld.wolfram.com/SineIntegral.html">
   Mathworld</A>. The implementation used is that of
-  <A HREF="http://wwwasdoc.web.cern.ch/wwwasdoc/shortwrupsdir/c336/top.html">
+  <A HREF="https://cern-tex.web.cern.ch/cern-tex/shortwrupsdir/c336/top.html">
   CERNLIB</A>,
   based on Y.L. Luke, The special functions and their approximations, v.II, (Academic Press, New York l969) 325-326.
 
@@ -219,7 +219,7 @@ namespace Math {
   For detailed description see
   <A HREF="http://mathworld.wolfram.com/CosineIntegral.html">
   Mathworld</A>. The implementation used is that of
-  <A HREF="http://wwwasdoc.web.cern.ch/wwwasdoc/shortwrupsdir/c336/top.html">
+  <A HREF="https://cern-tex.web.cern.ch/cern-tex/shortwrupsdir/c336/top.html">
   CERNLIB</A>,
   based on Y.L. Luke, The special functions and their approximations, v.II, (Academic Press, New York l969) 325-326.
 
diff --git a/math/mathmore/inc/Math/SpecFuncMathMore.h b/math/mathmore/inc/Math/SpecFuncMathMore.h
index 4ae823a8e036cdecd861318f9f99761c6839bf28..6cc22d6ef6e09106e6d2cbea074973dd6ed2c663 100644
--- a/math/mathmore/inc/Math/SpecFuncMathMore.h
+++ b/math/mathmore/inc/Math/SpecFuncMathMore.h
@@ -193,7 +193,7 @@ namespace Math {
   (<A HREF="http://www.gnu.org/software/gsl/manual/gsl-ref_7.html#SEC95">
   GSL</A>, <A HREF="http://planetmath.org/encyclopedia/EllipticIntegralsAndJacobiEllipticFunctions.html">
   Planetmath</A> and
-  <A HREF="http://wwwasdoc.web.cern.ch/wwwasdoc/shortwrupsdir/c346/top.html">
+  <A HREF="https://cern-tex.web.cern.ch/cern-tex/shortwrupsdir/c346/top.html">
   CERNLIB</A>) use the + sign in front of n in the denominator. In
   order to be C++ compliant, the present library uses the former
   convention. The implementation used is that of
@@ -408,7 +408,7 @@ namespace Math {
   (<A HREF="http://www.gnu.org/software/gsl/manual/gsl-ref_7.html#SEC95">
   GSL</A>, <A HREF="http://planetmath.org/encyclopedia/EllipticIntegralsAndJacobiEllipticFunctions.html">
   Planetmath</A> and
-  <A HREF="http://wwwasdoc.web.cern.ch/wwwasdoc/shortwrupsdir/c346/top.html">
+  <A HREF="https://cern-tex.web.cern.ch/cern-tex/shortwrupsdir/c346/top.html">
   CERNLIB</A>) use the + sign in front of n in the denominator. In
   order to be C++ compliant, the present library uses the former
   convention. The implementation used is that of
diff --git a/math/mathmore/inc/Math/Vavilov.h b/math/mathmore/inc/Math/Vavilov.h
index 3937f498cab999bc2dcc85f84c3e1ef5384fdcd0..6912bee43262f7b060b534116efd0c50afdbbf7b 100644
--- a/math/mathmore/inc/Math/Vavilov.h
+++ b/math/mathmore/inc/Math/Vavilov.h
@@ -92,14 +92,14 @@ namespace Math {
    A. Rotondi and P. Montagna, Fast calculation of Vavilov distribution,
    <A HREF="http://dx.doi.org/10.1016/0168-583X(90)90749-K">Nucl. Instr. and Meth. B47 (1990) 215-224</A>,
    which has been implemented in
-   <A HREF="http://wwwasdoc.web.cern.ch/wwwasdoc/shortwrupsdir/g115/top.html">
+   <A HREF="https://cern-tex.web.cern.ch/cern-tex/shortwrupsdir/g115/top.html">
    CERNLIB (G115)</A>.
 
    - VavilovAccurate uses the algorithm by
    B. Schorr, Programs for the Landau and the Vavilov distributions and the corresponding random numbers,
    <A HREF="http://dx.doi.org/10.1016/0010-4655(74)90091-5">Computer Phys. Comm. 7 (1974) 215-224</A>,
    which has been implemented in
-   <A HREF="http://wwwasdoc.web.cern.ch/wwwasdoc/shortwrupsdir/g116/top.html">
+   <A HREF="https://cern-tex.web.cern.ch/cern-tex/shortwrupsdir/g116/top.html">
    CERNLIB (G116)</A>.
 
    Both subclasses store coefficients needed to calculate \f$p(\lambda; \kappa, \beta^2)\f$
@@ -154,14 +154,14 @@ public:
    virtual double Pdf (double x, double kappa, double beta2) = 0;
 
    /**
-       Evaluate the Vavilov cummulative probability density function
+       Evaluate the Vavilov cumulative probability density function
 
        @param x The Landau parameter \f$x = \lambda_L\f$
    */
    virtual double Cdf (double x) const = 0;
 
    /**
-       Evaluate the Vavilov cummulative probability density function,
+       Evaluate the Vavilov cumulative probability density function,
        and set kappa and beta2, if necessary
 
        @param x The Landau parameter \f$x = \lambda_L\f$
@@ -171,14 +171,14 @@ public:
    virtual double Cdf (double x, double kappa, double beta2) = 0;
 
    /**
-       Evaluate the Vavilov complementary cummulative probability density function
+       Evaluate the Vavilov complementary cumulative probability density function
 
        @param x The Landau parameter \f$x = \lambda_L\f$
    */
    virtual double Cdf_c (double x) const = 0;
 
    /**
-       Evaluate the Vavilov complementary cummulative probability density function,
+       Evaluate the Vavilov complementary cumulative probability density function,
        and set kappa and beta2, if necessary
 
        @param x The Landau parameter \f$x = \lambda_L\f$
@@ -188,14 +188,14 @@ public:
    virtual double Cdf_c (double x, double kappa, double beta2) = 0;
 
    /**
-       Evaluate the inverse of the Vavilov cummulative probability density function
+       Evaluate the inverse of the Vavilov cumulative probability density function
 
        @param z The argument \f$z\f$, which must be in the range \f$0 \le z \le 1\f$
    */
    virtual double Quantile (double z) const = 0;
 
    /**
-       Evaluate the inverse of the Vavilov cummulative probability density function,
+       Evaluate the inverse of the Vavilov cumulative probability density function,
        and set kappa and beta2, if necessary
 
        @param z The argument \f$z\f$, which must be in the range \f$0 \le z \le 1\f$
@@ -205,14 +205,14 @@ public:
    virtual double Quantile (double z, double kappa, double beta2) = 0;
 
    /**
-       Evaluate the inverse of the complementary Vavilov cummulative probability density function
+       Evaluate the inverse of the complementary Vavilov cumulative probability density function
 
        @param z The argument \f$z\f$, which must be in the range \f$0 \le z \le 1\f$
    */
    virtual double Quantile_c (double z) const = 0;
 
    /**
-       Evaluate the inverse of the complementary Vavilov cummulative probability density function,
+       Evaluate the inverse of the complementary Vavilov cumulative probability density function,
        and set kappa and beta2, if necessary
 
        @param z The argument \f$z\f$, which must be in the range \f$0 \le z \le 1\f$
diff --git a/math/mathmore/inc/Math/VavilovAccurate.h b/math/mathmore/inc/Math/VavilovAccurate.h
index ac13f71a58ba9945a11debcdb13dcef03fab2aea..a9f57eb2f9081d4d9245aeab7d835a52caa5dca3 100644
--- a/math/mathmore/inc/Math/VavilovAccurate.h
+++ b/math/mathmore/inc/Math/VavilovAccurate.h
@@ -81,7 +81,7 @@ namespace Math {
    B. Schorr, Programs for the Landau and the Vavilov distributions and the corresponding random numbers,
    <A HREF="http://dx.doi.org/10.1016/0010-4655(74)90091-5">Computer Phys. Comm. 7 (1974) 215-224</A>,
    which has been implemented in
-   <A HREF="http://wwwasdoc.web.cern.ch/wwwasdoc/shortwrupsdir/g116/top.html">
+   <A HREF="https://cern-tex.web.cern.ch/cern-tex/shortwrupsdir/g116/top.html">
    CERNLIB (G116)</A>.
 
    The class stores coefficients needed to calculate \f$p(\lambda; \kappa, \beta^2)\f$
@@ -96,7 +96,7 @@ namespace Math {
 
    Two parameters which are fixed in the CERNLIB implementation may be set by the user:
    - epsilonPM corresponds to \f$\epsilon^+ = \epsilon^-\f$ in Eqs. (2.1) and (2.2) of Schorr's paper.
-   epsilonPM gives an estimate on the integral of the cummulative distribution function
+   epsilonPM gives an estimate on the integral of the cumulative distribution function
    outside the range \f$\lambda_{min} \le \lambda \le \lambda_{max}\f$
    where the approximation is valid.
    Thus, it determines the support of the approximation used here (called $T_0 - T_1$ in the paper).
@@ -109,7 +109,7 @@ namespace Math {
 
    For the quantile calculation, the algorithm given by Schorr is not used,
    because it turns out to be very slow and still inaccurate.
-   Instead, an initial estimate is calculated based on a precalculated table,
+   Instead, an initial estimate is calculated based on a pre-calculated table,
    which is subsequently improved by Newton iterations.
 
    While the CERNLIB implementation calculates at most 156 terms in the series expansion
@@ -138,7 +138,7 @@ public:
 
        @param kappa The parameter \f$\kappa\f$, which must be in the range \f$\kappa \ge 0.001 \f$
        @param beta2 The parameter \f$\beta^2\f$, which must be in the range \f$0 \le \beta^2 \le 1 \f$
-       @param epsilonPM: \f$\epsilon^+ = \epsilon^-\f$ in Eqs. (2.1) and (2.2) of Schorr's paper; gives an estimate on the integral of the cummulative distribution function
+       @param epsilonPM: \f$\epsilon^+ = \epsilon^-\f$ in Eqs. (2.1) and (2.2) of Schorr's paper; gives an estimate on the integral of the cumulative distribution function
               outside the range \f$\lambda_{min} \le \lambda \le \lambda_{max}\f$
               where the approximation is valid.
        @param epsilon: \f$\epsilon\f$ in Eq. (4.10) of Schorr's paper; determines the accuracy of the series expansion.
@@ -172,14 +172,14 @@ public:
    double Pdf (double x, double kappa, double beta2);
 
    /**
-       Evaluate the Vavilov cummulative probability density function
+       Evaluate the Vavilov cumulative probability density function
 
        @param x The Landau parameter \f$x = \lambda_L\f$
    */
    double Cdf (double x) const;
 
    /**
-       Evaluate the Vavilov cummulative probability density function,
+       Evaluate the Vavilov cumulative probability density function,
        and set kappa and beta2, if necessary
 
        @param x The Landau parameter \f$x = \lambda_L\f$
@@ -189,14 +189,14 @@ public:
    double Cdf (double x, double kappa, double beta2);
 
    /**
-       Evaluate the Vavilov complementary cummulative probability density function
+       Evaluate the Vavilov complementary cumulative probability density function
 
        @param x The Landau parameter \f$x = \lambda_L\f$
    */
    double Cdf_c (double x) const;
 
    /**
-       Evaluate the Vavilov complementary cummulative probability density function,
+       Evaluate the Vavilov complementary cumulative probability density function,
        and set kappa and beta2, if necessary
 
        @param x The Landau parameter \f$x = \lambda_L\f$
@@ -206,14 +206,14 @@ public:
    double Cdf_c (double x, double kappa, double beta2);
 
    /**
-       Evaluate the inverse of the Vavilov cummulative probability density function
+       Evaluate the inverse of the Vavilov cumulative probability density function
 
        @param z The argument \f$z\f$, which must be in the range \f$0 \le z \le 1\f$
    */
    double Quantile (double z) const;
 
    /**
-       Evaluate the inverse of the Vavilov cummulative probability density function,
+       Evaluate the inverse of the Vavilov cumulative probability density function,
        and set kappa and beta2, if necessary
 
        @param z The argument \f$z\f$, which must be in the range \f$0 \le z \le 1\f$
@@ -223,14 +223,14 @@ public:
    double Quantile (double z, double kappa, double beta2);
 
    /**
-       Evaluate the inverse of the complementary Vavilov cummulative probability density function
+       Evaluate the inverse of the complementary Vavilov cumulative probability density function
 
        @param z The argument \f$z\f$, which must be in the range \f$0 \le z \le 1\f$
    */
    double Quantile_c (double z) const;
 
    /**
-       Evaluate the inverse of the complementary Vavilov cummulative probability density function,
+       Evaluate the inverse of the complementary Vavilov cumulative probability density function,
        and set kappa and beta2, if necessary
 
        @param z The argument \f$z\f$, which must be in the range \f$0 \le z \le 1\f$
@@ -253,7 +253,7 @@ public:
 
        @param kappa The parameter \f$\kappa\f$, which must be in the range \f$\kappa \ge 0.001 \f$
        @param beta2 The parameter \f$\beta^2\f$, which must be in the range \f$0 \le \beta^2 \le 1 \f$
-       @param epsilonPM \f$\epsilon^+ = \epsilon^-\f$ in Eqs. (2.1) and (2.2) of Schorr's paper; gives an estimate on the integral of the cummulative distribution function
+       @param epsilonPM \f$\epsilon^+ = \epsilon^-\f$ in Eqs. (2.1) and (2.2) of Schorr's paper; gives an estimate on the integral of the cumulative distribution function
               outside the range \f$\lambda_{min} \le \lambda \le \lambda_{max}\f$
               where the approximation is valid.
        @param epsilon \f$\epsilon\f$ in Eq. (4.10) of Schorr's paper; determines the accuracy of the series expansion.
@@ -365,7 +365,7 @@ private:
 double vavilov_accurate_pdf (double x, double kappa, double beta2);
 
    /**
-       The Vavilov cummulative probability density function
+       The Vavilov cumulative probability density function
 
        @param x The Landau parameter \f$x = \lambda_L\f$
        @param kappa The parameter \f$\kappa\f$, which must be in the range \f$\kappa \ge 0.001 \f$
@@ -376,7 +376,7 @@ double vavilov_accurate_pdf (double x, double kappa, double beta2);
 double vavilov_accurate_cdf (double x, double kappa, double beta2);
 
    /**
-       The Vavilov complementary cummulative probability density function
+       The Vavilov complementary cumulative probability density function
 
        @param x The Landau parameter \f$x = \lambda_L\f$
        @param kappa The parameter \f$\kappa\f$, which must be in the range \f$\kappa \ge 0.001 \f$
@@ -387,7 +387,7 @@ double vavilov_accurate_cdf (double x, double kappa, double beta2);
 double vavilov_accurate_cdf_c (double x, double kappa, double beta2);
 
    /**
-       The inverse of the Vavilov cummulative probability density function
+       The inverse of the Vavilov cumulative probability density function
 
        @param z The argument \f$z\f$, which must be in the range \f$0 \le z \le 1\f$
        @param kappa The parameter \f$\kappa\f$, which must be in the range \f$\kappa \ge 0.001 \f$
@@ -398,7 +398,7 @@ double vavilov_accurate_cdf_c (double x, double kappa, double beta2);
 double vavilov_accurate_quantile (double z, double kappa, double beta2);
 
    /**
-       The inverse of the complementary Vavilov cummulative probability density function
+       The inverse of the complementary Vavilov cumulative probability density function
 
        @param z The argument \f$z\f$, which must be in the range \f$0 \le z \le 1\f$
        @param kappa The parameter \f$\kappa\f$, which must be in the range \f$\kappa \ge 0.001 \f$
diff --git a/math/mathmore/inc/Math/VavilovFast.h b/math/mathmore/inc/Math/VavilovFast.h
index df87d2e19cae5a959a5ef1d5f06daf4addfa9a8a..412640b8fdd4e4af3c680836bc80aff0ae2f0cd9 100644
--- a/math/mathmore/inc/Math/VavilovFast.h
+++ b/math/mathmore/inc/Math/VavilovFast.h
@@ -90,7 +90,7 @@ namespace Math {
    A. Rotondi and P. Montagna, Fast calculation of Vavilov distribution,
    <A HREF="http://dx.doi.org/10.1016/0168-583X(90)90749-K">Nucl. Instr. and Meth. B47 (1990) 215-224</A>,
    which has been implemented in
-   <A HREF="http://wwwasdoc.web.cern.ch/wwwasdoc/shortwrupsdir/g115/top.html">
+   <A HREF="https://cern-tex.web.cern.ch/cern-tex/shortwrupsdir/g115/top.html">
    CERNLIB (G115)</A>.
 
    The class stores coefficients needed to calculate \f$p(\lambda; \kappa, \beta^2)\f$
@@ -154,14 +154,14 @@ public:
    double Pdf (double x, double kappa, double beta2);
 
    /**
-       Evaluate the Vavilov cummulative probability density function
+       Evaluate the Vavilov cumulative probability density function
 
        @param x The Landau parameter \f$x = \lambda_L\f$
    */
    double Cdf (double x) const;
 
    /**
-       Evaluate the Vavilov cummulative probability density function,
+       Evaluate the Vavilov cumulative probability density function,
        and set kappa and beta2, if necessary
 
        @param x The Landau parameter \f$x = \lambda_L\f$
@@ -171,14 +171,14 @@ public:
    double Cdf (double x, double kappa, double beta2);
 
    /**
-       Evaluate the Vavilov complementary cummulative probability density function
+       Evaluate the Vavilov complementary cumulative probability density function
 
        @param x The Landau parameter \f$x = \lambda_L\f$
    */
    double Cdf_c (double x) const;
 
    /**
-       Evaluate the Vavilov complementary cummulative probability density function,
+       Evaluate the Vavilov complementary cumulative probability density function,
        and set kappa and beta2, if necessary
 
        @param x The Landau parameter \f$x = \lambda_L\f$
@@ -188,14 +188,14 @@ public:
    double Cdf_c (double x, double kappa, double beta2);
 
    /**
-       Evaluate the inverse of the Vavilov cummulative probability density function
+       Evaluate the inverse of the Vavilov cumulative probability density function
 
        @param z The argument \f$z\f$, which must be in the range \f$0 \le z \le 1\f$
    */
    double Quantile (double z) const;
 
    /**
-       Evaluate the inverse of the Vavilov cummulative probability density function,
+       Evaluate the inverse of the Vavilov cumulative probability density function,
        and set kappa and beta2, if necessary
 
        @param z The argument \f$z\f$, which must be in the range \f$0 \le z \le 1\f$
@@ -205,14 +205,14 @@ public:
    double Quantile (double z, double kappa, double beta2);
 
    /**
-       Evaluate the inverse of the complementary Vavilov cummulative probability density function
+       Evaluate the inverse of the complementary Vavilov cumulative probability density function
 
        @param z The argument \f$z\f$, which must be in the range \f$0 \le z \le 1\f$
    */
    double Quantile_c (double z) const;
 
    /**
-       Evaluate the inverse of the complementary Vavilov cummulative probability density function,
+       Evaluate the inverse of the complementary Vavilov cumulative probability density function,
        and set kappa and beta2, if necessary
 
        @param z The argument \f$z\f$, which must be in the range \f$0 \le z \le 1\f$
@@ -292,7 +292,7 @@ private:
 double vavilov_fast_pdf (double x, double kappa, double beta2);
 
    /**
-       The Vavilov cummulative probability density function
+       The Vavilov cumulative probability density function
 
        @param x The Landau parameter \f$x = \lambda_L\f$
        @param kappa The parameter \f$\kappa\f$, which must be in the range \f$0.01 \le \kappa \le 12 \f$
@@ -303,7 +303,7 @@ double vavilov_fast_pdf (double x, double kappa, double beta2);
 double vavilov_fast_cdf (double x, double kappa, double beta2);
 
    /**
-       The Vavilov complementary cummulative probability density function
+       The Vavilov complementary cumulative probability density function
 
        @param x The Landau parameter \f$x = \lambda_L\f$
        @param kappa The parameter \f$\kappa\f$, which must be in the range \f$0.01 \le \kappa \le 12 \f$
@@ -314,7 +314,7 @@ double vavilov_fast_cdf (double x, double kappa, double beta2);
 double vavilov_fast_cdf_c (double x, double kappa, double beta2);
 
    /**
-       The inverse of the Vavilov cummulative probability density function
+       The inverse of the Vavilov cumulative probability density function
 
        @param z The argument \f$z\f$, which must be in the range \f$0 \le z \le 1\f$
        @param kappa The parameter \f$\kappa\f$, which must be in the range \f$0.01 \le \kappa \le 12 \f$
@@ -325,7 +325,7 @@ double vavilov_fast_cdf_c (double x, double kappa, double beta2);
 double vavilov_fast_quantile (double z, double kappa, double beta2);
 
    /**
-       The inverse of the complementary Vavilov cummulative probability density function
+       The inverse of the complementary Vavilov cumulative probability density function
 
        @param z The argument \f$z\f$, which must be in the range \f$0 \le z \le 1\f$
        @param kappa The parameter \f$\kappa\f$, which must be in the range \f$0.01 \le \kappa \le 12 \f$
diff --git a/math/mathmore/src/SpecFuncMathMore.cxx b/math/mathmore/src/SpecFuncMathMore.cxx
index b0fa46f3f6284fe8322c517bbb1d919684feb4cd..2f7052d5886377932bf92e3855f0e55e96c33b42 100644
--- a/math/mathmore/src/SpecFuncMathMore.cxx
+++ b/math/mathmore/src/SpecFuncMathMore.cxx
@@ -103,7 +103,7 @@ the former is adopted by
      http://planetmath.org/encyclopedia/EllipticIntegralsAndJacobiEllipticFunctions.html
 
 - CERNLIB
-     http://wwwasdoc.web.cern.ch/wwwasdoc/shortwrupsdir/c346/top.html
+     https://cern-tex.web.cern.ch/cern-tex/shortwrupsdir/c346/top.html
 
    while the latter is used by
 
@@ -239,7 +239,7 @@ the former is adopted by
      http://planetmath.org/encyclopedia/EllipticIntegralsAndJacobiEllipticFunctions.html
 
 - CERNLIB
-     http://wwwasdoc.web.cern.ch/wwwasdoc/shortwrupsdir/c346/top.html
+     https://cern-tex.web.cern.ch/cern-tex/shortwrupsdir/c346/top.html
 
    while the latter is used by
 
diff --git a/math/minuit/doc/index.txt b/math/minuit/doc/index.txt
index b128bc9b5b23ecfeb9f510ec10b1c40c4009c921..08534001bbffab5d3b5c02c6a5d283e71563c8af 100644
--- a/math/minuit/doc/index.txt
+++ b/math/minuit/doc/index.txt
@@ -5,7 +5,7 @@ BEGIN_HTML
 <li>The main TMinuit class is documented in class TMinuit.</li>
 <li><a href="ftp://root.cern.ch/root/doc/5FittingHistograms.pdf">The Chapter about Fitting Histogram in the Users Guide
     </a></li>
-<li><a href="http://wwwasdoc.web.cern.ch/wwwasdoc/minuit/minmain.html">The MINUIT documentation in CERNLIB
+<li><a href="https://cern-tex.web.cern.ch/cern-tex/minuit/minmain.html">The MINUIT documentation in CERNLIB
     </a></li>
 <li><a href="http://root.cern.ch/drupal/content/howtos#fit">How to Fit Histograms
       </A></li>
diff --git a/math/minuit2/doc/Minuit2.html b/math/minuit2/doc/Minuit2.html
index 9ced290ab918df36eff1133738978c660e6f4702..988ae86ab276609abb54ab75c7cd897f14204bf6 100644
--- a/math/minuit2/doc/Minuit2.html
+++ b/math/minuit2/doc/Minuit2.html
@@ -22,17 +22,17 @@ In addition, the %ROOT distribution contains classes needed to integrate Minuit2
 <p>
 A new class has been introduced, ROOT::Minuit2::Minuit2Minimizer, which implements the interface
 ROOT::Math::Minimizer. Within %ROOT, it can be instantiates also using the %ROOT plug-in manager. This class provides a convenient entry point for using Minuit2. An example of using this interface is
-the %ROOT tutorial <em>tutorials/fit/NumericalMinimization.C</em> or  
+the %ROOT tutorial <em>tutorials/fit/NumericalMinimization.C</em> or
 the Minuit2 test program <a href="http://root.cern.ch/viewvc/trunk/math/minuit2/test/testMinimize.cxx?view=markup"><tt>testMinimize.cxx</tt></a>.
 <p>
-A standalone version of Minuit2 (indipendent of %ROOT) can be downloaded from <A HREF="../Minuit2.tar.gz">here</A>. It does not contain the %ROOT interface and it is therefore totally independent of external packages and can be simply build using the <em>configure</em> script and then <em>make</em>. Example tests are provided in the directory <em>test/MnSim</em> and <em>test/MnTutorial</em> and they can be built with the <em>make check</em> command.
+A standalone version of Minuit2 (independent of %ROOT) can be downloaded from <A HREF="../Minuit2.tar.gz">here</A>. It does not contain the %ROOT interface and it is therefore totally independent of external packages and can be simply build using the <em>configure</em> script and then <em>make</em>. Example tests are provided in the directory <em>test/MnSim</em> and <em>test/MnTutorial</em> and they can be built with the <em>make check</em> command.
 <br>
 The <a  href="https://root.cern.ch/root/htmldoc/guides/minuit2/Minuit2.html">Minuit2 User Guide</a> provides all the information needed for using directly (without add-on packages like %ROOT) Minuit2.
 
 
 <h2>References</h2>
 <ol>
-<li>F. James, <em>Fortran MINUIT Reference Manual</em> (<a href="http://wwwasdoc.web.cern.ch/wwwasdoc/minuit/minmain.html">html</a>);
+<li>F. James, <em>Fortran MINUIT Reference Manual</em> (<a href="https://cern-tex.web.cern.ch/cern-tex/minuit/minmain.html">html</a>);
 <li>F. James and M. Winkler, <em>C++ MINUIT User's Guide</em> (<a href="https://root.cern.ch/root/htmldoc/guides/minuit2/Minuit2.html">html</a> and
   <a href="https://root.cern.ch/root/htmldoc/guides/minuit2/Minuit2.pdf">pdf</a>);
 <li>F. James, <em>Minuit Tutorial on Function Minimization</em> (<a href="http://seal.cern.ch/documents/minuit/mntutorial.pdf">pdf</a>);
diff --git a/math/minuit2/doc/Minuit2.md b/math/minuit2/doc/Minuit2.md
index 699355230bea876fc3973545e80b00ee77cb2c90..66abf7f563a98113ee57dc3b6e1b38d48163d515 100644
--- a/math/minuit2/doc/Minuit2.md
+++ b/math/minuit2/doc/Minuit2.md
@@ -9,12 +9,12 @@ Minuit2, originally developed in the SEAL project, is now distributed within %RO
 
 A new class has been introduced, ROOT::Minuit2::Minuit2Minimizer, which implements the interface ROOT::Math::Minimizer. Within %ROOT, it can be instantiates also using the %ROOT plug-in manager. This class provides a convenient entry point for using Minuit2\. An example of using this interface is the %ROOT tutorial _tutorials/fit/NumericalMinimization.C_ or the Minuit2 test program [<tt>testMinimize.cxx</tt>](http://root.cern.ch/viewvc/trunk/math/minuit2/test/testMinimize.cxx?view=markup).
 
-A standalone version of Minuit2 (indipendent of %ROOT) can be downloaded from [here](../Minuit2.tar.gz). It does not contain the %ROOT interface and it is therefore totally independent of external packages and can be simply build using the _configure_ script and then _make_. Example tests are provided in the directory _test/MnSim_ and _test/MnTutorial_ and they can be built with the _make check_ command.   
+A standalone version of Minuit2 (independent of %ROOT) can be downloaded from [here](../Minuit2.tar.gz). It does not contain the %ROOT interface and it is therefore totally independent of external packages and can be simply build using the _configure_ script and then _make_. Example tests are provided in the directory _test/MnSim_ and _test/MnTutorial_ and they can be built with the _make check_ command.
 The [Minuit2 User Guide](https://root.cern.ch/root/htmldoc/guides/minuit2/Minuit2.html) provides all the information needed for using directly (without add-on packages like %ROOT) Minuit2.
 
 ## References
 
-1.  F. James, _Fortran MINUIT Reference Manual_ ([html](http://wwwasdoc.web.cern.ch/wwwasdoc/minuit/minmain.html));
+1.  F. James, _Fortran MINUIT Reference Manual_ ([html](https://cern-tex.web.cern.ch/cern-tex/minuit/minmain.html));
 2.  F. James and M. Winkler, _C++ MINUIT User's Guide_ ([html](https://root.cern.ch/root/htmldoc/guides/minuit2/Minuit2.html) and [pdf](https://root.cern.ch/root/htmldoc/guides/minuit2/Minuit2.pdf));
 3.  F. James, _Minuit Tutorial on Function Minimization_ ([pdf](http://seal.cern.ch/documents/minuit/mntutorial.pdf));
 4.  F. James, _The Interpretation of Errors in Minuit_ ([pdf](http://seal.cern.ch/documents/minuit/mnerror.pdf));
diff --git a/math/physics/doc/index.md b/math/physics/doc/index.md
index 8ab736cda48a491574bd5cfede8faed85c734501..1fdee8fa1f5c07a882b9bb6443f9f7c012843157 100644
--- a/math/physics/doc/index.md
+++ b/math/physics/doc/index.md
@@ -17,4 +17,4 @@ Several documents describing these classes are listed below:
 It is a combination of CLHEPs Vector package written by
 Leif Lonnblad, Andreas Nilsson and Evgueni Tcherniaev
 and a ROOT package written by Pasha Murat.
-for CLHEP see:  http://wwwinfo.cern.ch/asd/lhc++/clhep/
\ No newline at end of file
+for CLHEP see:  http://www.cern.ch/clhep/
\ No newline at end of file
diff --git a/math/smatrix/doc/SMatrixClass.md b/math/smatrix/doc/SMatrixClass.md
index be43d4a27a54a5c2f62196e7248c44c94df95788..00847d9b1411669528893bbc005001469ec2de23 100644
--- a/math/smatrix/doc/SMatrixClass.md
+++ b/math/smatrix/doc/SMatrixClass.md
@@ -26,37 +26,37 @@ The following constructors are available to create a matrix:
 
 Here are some examples on how to create a matrix. We use _typedef's_ in the following examples to avoid the full C++ names for the matrix classes. Notice that for a general matrix the representation has the default value, ROOT::Math::MatRepStd, and it is not needed to be specified. Furtheremore, for a general square matrix, the number of column may be as well omitted.
 
-<pre>_// typedef definitions used in the following declarations_ 
-typedef ROOT::Math::SMatrix<double,3>                                       SMatrix33;      
+<pre>_// typedef definitions used in the following declarations_
+typedef ROOT::Math::SMatrix<double,3>                                       SMatrix33;
 typedef ROOT::Math::SMatrix<double,2>                                       SMatrix22;
 typedef ROOT::Math::SMatrix<double,3,3,ROOT::Math::MatRepSym<double,3> >    SMatrixSym3;
-typedef ROOT::Math::SVector>double,2>                                       SVector2; 
+typedef ROOT::Math::SVector>double,2>                                       SVector2;
 typedef ROOT::Math::SVector>double,3>                                       SVector3;
-typedef ROOT::Math::SVector>double,6>                                       SVector6; 
+typedef ROOT::Math::SVector>double,6>                                       SVector6;
 
 SMatrix33   m0;                         _// create a zero 3x3 matrix_
-_// create an 3x3 identity matrix_ 
-SMatrix33   i = ROOT::Math::SMatrixIdentity();      
+_// create an 3x3 identity matrix_
+SMatrix33   i = ROOT::Math::SMatrixIdentity();
 double   a[9] = {1,2,3,4,5,6,7,8,9};    _// input matrix data_
 SMatrix33   m(a,9);                     _// create a matrix using the a[] data_
 _// this will produce the 3x3 matrix
-//    (  1    2    3 
+//    (  1    2    3
 //       4    5    6
 //       7    8    9  )_
 </pre>
 
 Example to create a symmetric matrix from an _std::vector_:
 
-<pre>std::vector<double> v(6);         
+<pre>std::vector<double> v(6);
 for (int i = 0; i<6; ++i) v[i] = double(i+1);
-SMatrixSym3  s(v.begin(),v.end())                   
+SMatrixSym3  s(v.begin(),v.end())
 _// this will produce the symmetric  matrix
-//    (  1    2    4 
+//    (  1    2    4
 //       2    3    5
 //       4    5    6  )_
 
 _// create a a general matrix from a symmetric matrix. The opposite will not compile_
-SMatrix33    m2 = s;                   
+SMatrix33    m2 = s;
 </pre>
 
 Example to create a symmetric matrix from a ROOT::Math::SVector contining the lower/upper data block:
@@ -64,11 +64,11 @@ Example to create a symmetric matrix from a ROOT::Math::SVector contining the lo
 <pre>ROOT::Math::SVectorr<double, 6> v(1,2,3,4,5,6);
 SMatrixSym3 s1(v);  // lower block (default)
 // this will produce the symmetric  matrix
-//    (  1    2    4 
+//    (  1    2    4
 //       2    3    5
 //       4    5    6  )
 
-SMatrixSym3 s2(v,false);  // upper block 
+SMatrixSym3 s2(v,false);  // upper block
 // this will produce the symmetric  matrix
 //    (  1    2    3
 //       2    4    5
@@ -77,76 +77,83 @@ SMatrixSym3 s2(v,false);  // upper block
 
 ### Accessing and Setting Methods
 
-The matrix elements can be set using the _operator()(irow,icol)_, where irow and icol are the row and column indexes or by using the iterator interface. Notice that the indexes start from zero and not from one as in FORTRAN. All the matrix elements can be set also by using the ROOT::Math::SetElements function passing a generic iterator.   
+The matrix elements can be set using the _operator()(irow,icol)_, where irow and icol are the row and column indexes or by using the iterator interface. Notice that the indexes start from zero and not from one as in FORTRAN. All the matrix elements can be set also by using the ROOT::Math::SetElements function passing a generic iterator.
 The elements can be accessed by these same methods and also by using the ROOT::Math::SMatrix::apply function. The _apply(i)_ function has exactly the same behavior for general and symmetric matrices, in contrast to the iterator access methods which behave differently (it follows the data order).
 
-<pre>SMatrix33   m; 
-m(0,0)  = 1;                          _ // set the element in first row and first column_     
+<pre>SMatrix33   m;
+m(0,0)  = 1;                          _ // set the element in first row and first column_
 *(m.**begin**()+1) = 2;                    _// set the second element (0,1)_
 double d[9]={1,2,3,4,5,6,7,8,9};
 m.SetElements(d,d+9);                  _// set the d[] values in m_
 
 double x = m(2,1);                     _// return the element in third row and first column_
-x = m.**apply**(7);                        _// return the 8-th element (row=2,col=1)_ 
+x = m.**apply**(7);                        _// return the 8-th element (row=2,col=1)_
 x = *(m.**begin**()+7);                    _// return the 8-th element (row=2,col=1)_
 _// symmetric matrices (note the difference in behavior between apply and the iterators)_
-x = *(m.**begin**()+4)                     _// return the element (row=2,col=1)._ 
-x = m.**apply**(7);                        _// returns again the (row=2,col=1) element_                                        
+x = *(m.**begin**()+4)                     _// return the element (row=2,col=1)._
+x = m.**apply**(7);                        _// returns again the (row=2,col=1) element_
 </pre>
 
 There are methods to place and/or retrieve ROOT::Math::SVector objects as rows or columns in (from) a matrix. In addition one can put (get) a sub-matrix as another ROOT::Math::SMatrix object in a matrix. If the size of the the sub-vector or sub-matrix are larger than the matrix size a static assert ( a compilation error) is produced. The non-const methods are:
 
-<pre> 
+<pre>
 
 SMatrix33            m;
 SVector2       v2(1,2);
 _// place a vector of size 2 in the first row starting from element (0,1) : m(0,1) = v2[0]_
-m.**Place_in_row**(v2,0,1); 
-_// place the vector in the second column from (0,1) : m(0,1) = v2[0]   _             
-m.**Place in_col**(v2,0,1);                
+m.**Place_in_row**(v2,0,1);
+_// place the vector in the second column from (0,1) : m(0,1) = v2[0]   _
+m.**Place in_col**(v2,0,1);
 SMatrix22           m2;
-_// place the sub-matrix m2 in m starting from the element (1,1) : m(1,1) = m2(0,0)  _ 
-m.**Place_at**(m2,1,1);                    
+_// place the sub-matrix m2 in m starting from the element (1,1) : m(1,1) = m2(0,0)  _
+m.**Place_at**(m2,1,1);
 SVector3     v3(1,2,3);
 _// set v3 as the diagonal elements of m  : m(i,i) = v3[i] for i=0,1,2_
 m.**SetDiagonal**(v3)                    </pre>
 
 The const methods retrieving contents (getting slices of a matrix) are:
 
-<pre>a = {1,2,3,4,5,6,7,8,9}; 
-SMatrix33       m(a,a+9); 
-SVector3 irow = m.**Row**(0);             _// return as vector the first matrix row_ 
-SVector3 jcol = m.**Col**(1);            _// return as vector the second matrix column_ 
+<pre>a = {1,2,3,4,5,6,7,8,9};
+SMatrix33       m(a,a+9);
+SVector3 irow = m.**Row**(0);             _// return as vector the first matrix row_
+SVector3 jcol = m.**Col**(1);            _// return as vector the second matrix column_
 _// return a slice of the first row from element (0,1) : r2[0] = m(0,1); r2[1] = m(0,2)_
-SVector2 r2   =  m.**SubRow**<SVector2> (0,1);    
+SVector2 r2   =  m.**SubRow**<SVector2> (0,1);
 _// return a slice of the second column from element (0,1) : c2[0] = m(0,1); c2[1] = m(1,1);_
-SVector2 c2   =  m.**SubCol**<SVector2> (1,0);   
+SVector2 c2   =  m.**SubCol**<SVector2> (1,0);
 _// return a sub-matrix 2x2 with the upper left corner at the values (1,1)_
-SMatrix22 subM = m.**Sub**<SMatrix22>   (1,1); 
+SMatrix22 subM = m.**Sub**<SMatrix22>   (1,1);
 _// return the diagonal element in a SVector_
-SVector3  diag = m.**Diagonal**(); 
+SVector3  diag = m.**Diagonal**();
 _// return the upper(lower) block of the matrix m_
 SVector6 vub = m.**UpperBlock**();        _//  vub = [ 1, 2, 3, 5, 6, 9 ]_
-SVector6 vlb = m.**LowerBlock**();       _//  vlb = [ 1, 4, 5, 7, 8, 9 ]_ 
+SVector6 vlb = m.**LowerBlock**();       _//  vlb = [ 1, 4, 5, 7, 8, 9 ]_
 </pre>
 
 ### Linear Algebra Functions
 
-Only limited linear algebra functionality is available for SMatrix. It is possible for squared matrices NxN, to find the inverse or to calculate the determinant. Different inversion algorithms are used if the matrix is smaller than 6x6 or if it is symmetric. In the case of a small matrix, a faster direct inversion is used. For a large (N > 6) symmetric matrix the Bunch-Kaufman diagonal pivoting method is used while for a large (N > 6) general matrix an LU factorization is performed using the same algorithm as in the CERNLIB routine [dinv](http://wwwasdoc.web.cern.ch/wwwasdoc/shortwrupsdir/f010/top.html).
+Only limited linear algebra functionality is available for SMatrix. It is possible
+for squared matrices NxN, to find the inverse or to calculate the determinant.
+Different inversion algorithms are used if the matrix is smaller than 6x6 or if it
+is symmetric. In the case of a small matrix, a faster direct inversion is used.
+For a large (N > 6) symmetric matrix the Bunch-Kaufman diagonal pivoting method
+is used while for a large (N > 6) general matrix an LU factorization is performed
+using the same algorithm as in the CERNLIB routine
+[dinv](https://cern-tex.web.cern.ch/cern-tex/shortwrupsdir/f010/top.html).
 
 <pre>_//  Invert a NxN matrix. The inverted matrix replace the existing one and returns if the result is successful_
-bool ret = m.**Invert**()  
-_// return the inverse matrix of m. If the inversion fails ifail is different than zero_     
+bool ret = m.**Invert**()
+_// return the inverse matrix of m. If the inversion fails ifail is different than zero_
 int ifail = 0;
-mInv = m.**Inverse**(ifail);  
+mInv = m.**Inverse**(ifail);
 </pre>
 
 The determinant of a square matrix can be obtained as follows:
 
-<pre>double det; 
-_// calculate the determinant modyfing the matrix content. Returns if the calculation was successful_
-bool ret = m.**Det**(det);    
-_// calculate the determinant using a temporary matrix but preserving the matrix content_ 
+<pre>double det;
+_// calculate the determinant modifying the matrix content. Returns if the calculation was successful_
+bool ret = m.**Det**(det);
+_// calculate the determinant using a temporary matrix but preserving the matrix content_
 bool ret = n.**Det2**(det);
 </pre>
 
diff --git a/misc/table/src/TPolyLineShape.cxx b/misc/table/src/TPolyLineShape.cxx
index 971ef5843770a09e9707f153893f37ecd6f12913..f7b8b36545d67fb7e2ba2b408e905c4cf9be64a5 100644
--- a/misc/table/src/TPolyLineShape.cxx
+++ b/misc/table/src/TPolyLineShape.cxx
@@ -47,8 +47,8 @@
 //           V               v      v                     v      v                  //
 //      TPolyLineShape     TBRIK  TTUBE                 TPCON  TTRD1                //
 //       |        ^                                                                 //
-//       |        |       begin_html <a href="http://root.cern.ch/root/html/TShape.html#TShape:description">R  O  O  T        S  H  A  P  E  S</a>end_html                          //
-//       V        |       (see begin_html <a href="http://wwwinfo.cern.ch/asdoc/geant_html3/node109.html#SECTION041000000000000000000000">GEANT 3.21 shapes</a>end_html as well)                           //
+//       |        |       <a href="http://root.cern.ch/root/html/TShape.html#TShape:description">R  O  O  T        S  H  A  P  E  S</a>                          //
+//       V        |       (see <a href="https://cern-tex.web.cern.ch/cern-tex/geant_html3/node109.html#SECTION041000000000000000000000">GEANT 3.21 shapes</a> as well)                           //
 // St_PolyLine3D  |                                                                 //
 //                |                                                                 //
 //           TPoints3DABC                                                           //
@@ -467,7 +467,7 @@ void TPolyLineShape::PaintPolyMarker(Int_t n, Float_t *, Marker_t, Option_t *)
    TView *view = gPad->GetView();      //Get current 3-D view
    if(!view) return;                   //Check if `view` is valid
 
-   //Create temorary storage
+   //Create temporary storage
    TPoint *pxy = new TPoint[n];
    Float_t *x  = new Float_t[n];
    Float_t *y  = new Float_t[n];
diff --git a/misc/table/src/TVolume.cxx b/misc/table/src/TVolume.cxx
index a709e778193cc9af0c1b1247bb2186dd573995c4..44a5e5bd96945666c944d17b3a17eceb0c6a84e2 100644
--- a/misc/table/src/TVolume.cxx
+++ b/misc/table/src/TVolume.cxx
@@ -47,28 +47,24 @@ static TRotMatrix *gIdentity = 0;
 
 ClassImp(TVolume)
 
-//______________________________________________________________________________
-//*-*-*-*-*-*-*-*-*-*-*-* T V O L U M E  description *-*-*-*-*-*-*-*-*-*-*-*-*
-//*-*                     ==========================
-//*-*
-//*-*    A TVolume object is used to build the geometry hierarchy.
-//*-*    Since TVolume is derived from TDataSet class it may contain other volumes.
-//*-*
-//*-*    A geometry volume has attributes:
-//*-*      - name and title
-//*-*      - pointer to the referenced shape (see TShape).
-//*-*      - list of TVolumePosition object defining the position of the nested volumes
-//*-*        with respect to the mother node.
-//*-*
-//*-*
-//*-*    A volume can be drawn.
-//*-*
-//*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
+////////////////////////////////////////////////////////////////////////////////
+/// TVolume  description
+///
+///    A TVolume object is used to build the geometry hierarchy.
+///    Since TVolume is derived from TDataSet class it may contain other volumes.
+///
+///    A geometry volume has attributes:
+///      - name and title
+///      - pointer to the referenced shape (see TShape).
+///      - list of TVolumePosition object defining the position of the nested volumes
+///        with respect to the mother node.
+///
+///
+///    A volume can be drawn.
 
 
 ////////////////////////////////////////////////////////////////////////////////
-///*-*-*-*-*-*-*-*-*-*-*Volume default constructor*-*-*-*-*-*-*-*-*-*-*-*-*
-///*-*                  ========================
+//// Volume default constructor
 
 TVolume::TVolume()
 {
@@ -79,20 +75,17 @@ TVolume::TVolume()
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-///*-*-*-*-*-*-*-*-*-*-*Volume normal constructor*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
-///*-*                  =========================
-///*-*
-///*-*    name    is the name of the node
-///*-*    title   is title
-///*-*    shapename is the name of the referenced shape
-///*-*
-///*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
+//// Volume normal constructor
+////
+////    name    is the name of the node
+////    title   is title
+////    shapename is the name of the referenced shape
 
 TVolume::TVolume(const char *name, const char *title, const char *shapename, Option_t *option)
        :TObjectSet(name),TAttLine(), TAttFill(),fShape(0),fListOfShapes(0)
 {
 #ifdef WIN32
-//*-* The color "1" - default produces a very bad 3D image with OpenGL
+/// The color "1" - default produces a very bad 3D image with OpenGL
    Color_t lcolor = 16;
    SetLineColor(lcolor);
 #endif
@@ -109,22 +102,18 @@ TVolume::TVolume(const char *name, const char *title, const char *shapename, Opt
    if(fShape) ImportShapeAttributes();
 }
 
-
 ////////////////////////////////////////////////////////////////////////////////
-///*-*-*-*-*-*-*-*-*-*-*Volume normal constructor*-*-*-*-*-*-*-*-*-*-*
-///*-*                  ================================
-///*-*
-///*-*    name    is the name of the node
-///*-*    title   is title
-///*-*    shape   is the pointer to the shape definition
-///*-*
-///*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
+//// Volume normal constructor
+////
+////    name    is the name of the node
+////    title   is title
+////    shape   is the pointer to the shape definition
 
 TVolume::TVolume(const char *name, const char *title, TShape *shape, Option_t *option)
                 :TObjectSet(name),TAttLine(),TAttFill(),fShape(0),fListOfShapes(0)
 {
 #ifdef WIN32
-//*-* The color "1" - default produces a very bad 3D image with OpenGL
+/// The color "1" - default produces a very bad 3D image with OpenGL
    Color_t lcolor = 16;
    SetLineColor(lcolor);
 #endif
@@ -139,10 +128,10 @@ TVolume::TVolume(const char *name, const char *title, TShape *shape, Option_t *o
 
 ////////////////////////////////////////////////////////////////////////////////
 /// ENodeSEEN Visibility flag  00 - everything visible,
-///                            10 - this unvisible, but sons are visible
+///                            10 - this invisible, but sons are visible
 ///                            01 - this visible but sons
 ///                            11 - neither this nor its sons are visible
-/// Maps the value of the visibility flag to begin_html <a href="http://wwwinfo.cern.ch/asdoc/geant_html3/node128.html#SECTION056000000000000000000000">GEANT 3.21 "volume attributes"</a>end_html
+/// Maps the value of the visibility flag to <a href="https://cern-tex.web.cern.ch/cern-tex/geant_html3/node128.html#SECTION056000000000000000000000">GEANT 3.21 "volume attributes"</a>
 
 Int_t TVolume::MapStNode2GEANTVis(ENodeSEEN  vis)
 {
@@ -150,11 +139,12 @@ Int_t TVolume::MapStNode2GEANTVis(ENodeSEEN  vis)
    return mapVis[vis];
 }
 
-//______________________________________________________________________________
-//ENodeSEEN TVolume::MapGEANT2StNodeVis(Int_t vis)
+////////////////////////////////////////////////////////////////////////////////
+/// ENodeSEEN TVolume::MapGEANT2StNodeVis(Int_t vis)
+/// Maps the value of <a href="https://cern-tex.web.cern.ch/cern-tex/geant_html3/node128.html#SECTION056000000000000000000000">GEANT 3.21 "volume attributes"</a> to the visibility flag
+
 Int_t TVolume::MapGEANT2StNodeVis(Int_t vis)
 {
-// Maps the value of begin_html <a href="http://wwwinfo.cern.ch/asdoc/geant_html3/node128.html#SECTION056000000000000000000000">GEANT 3.21 "volume attributes"</a>end_html to the visibility flag
    const Int_t mapVis[4] = {1, -2, 0, -1 };
    Int_t i;
 //  for (i =0; i<3;i++) if (mapVis[i] == vis) return (ENodeSEEN)i;
@@ -244,8 +234,7 @@ TNode *TVolume::CreateTNode(const TVolumePosition *position)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-///*-*-*-*-*-*-*-*-*-*-*Volume default destructor*-*-*-*-*-*-*-*-*-*-*-*-*-*
-///*-*                  ======================
+//// Volume default destructor
 
 TVolume::~TVolume()
 {
@@ -260,7 +249,7 @@ TVolume::~TVolume()
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-///to be documented
+/// to be documented
 
 void TVolume::Add(TVolumePosition *position)
 {
@@ -270,7 +259,7 @@ void TVolume::Add(TVolumePosition *position)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-///to be documented
+/// to be documented
 
 TVolumePosition *TVolume::Add(TVolume *node, TVolumePosition *nodePosition)
 {
@@ -284,12 +273,11 @@ TVolumePosition *TVolume::Add(TVolume *node, TVolumePosition *nodePosition)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-///*-*
-///*-*    volume  the pointer to the volume to be placed
-///*-*    x,y,z   are the offsets of the volume with respect to his mother
-///*-*    matrix  is the pointer to the rotation matrix
-///*-*     id     is a unique position id
-///*-*
+////
+////    volume  the pointer to the volume to be placed
+////    x,y,z   are the offsets of the volume with respect to his mother
+////    matrix  is the pointer to the rotation matrix
+////     id     is a unique position id
 
 TVolumePosition *TVolume::Add(TVolume *volume, Double_t x, Double_t y, Double_t z,
                               TRotMatrix *matrix,  UInt_t id, Option_t *)
@@ -303,12 +291,11 @@ TVolumePosition *TVolume::Add(TVolume *volume, Double_t x, Double_t y, Double_t
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-///*-*
-///*-*    volume      the pointer to the volume to be placed
-///*-*    x,y,z       are the offsets of the volume with respect to his mother
-///*-*    matrixname  is the name of the rotation matrix
-///*-*     id         is a unique position id
-///*-*
+////
+////    volume      the pointer to the volume to be placed
+////    x,y,z       are the offsets of the volume with respect to his mother
+////    matrixname  is the name of the rotation matrix
+////     id         is a unique position id
 
 TVolumePosition *TVolume::Add(TVolume *volume, Double_t x, Double_t y, Double_t z,
                               const char *matrixname,  UInt_t id, Option_t *)
@@ -323,7 +310,7 @@ TVolumePosition *TVolume::Add(TVolume *volume, Double_t x, Double_t y, Double_t
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-///to be documented
+/// to be documented
 
 void TVolume::Browse(TBrowser *b)
 {
@@ -344,7 +331,7 @@ void TVolume::Browse(TBrowser *b)
    }
 }
 ////////////////////////////////////////////////////////////////////////////////
-///to be documented
+/// to be documented
 
 Int_t TVolume::DistancetoPrimitive(Int_t px, Int_t py)
 {
@@ -352,15 +339,13 @@ Int_t TVolume::DistancetoPrimitive(Int_t px, Int_t py)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-///*-*-*-*-*-*-*-*-*Compute distance from point px,py to a TVolumeView*-*-*-*-*-*
-///*-*                  ===========================================
-///*-*  Compute the closest distance of approach from point px,py to the position of
-///*-*  this volume.
-///*-*  The distance is computed in pixels units.
-///*-*
-///*-*  It is restricted by 2 levels of TVolumes
-///*-*
-///*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
+//// Compute distance from point px,py to a TVolumeView
+///
+////  Compute the closest distance of approach from point px,py to the position of
+////  this volume.
+////  The distance is computed in pixels units.
+////
+////  It is restricted by 2 levels of TVolumes
 
 Int_t TVolume::DistancetoNodePrimitive(Int_t px, Int_t py,TVolumePosition *pos)
 {
@@ -375,7 +360,7 @@ Int_t TVolume::DistancetoNodePrimitive(Int_t px, Int_t py,TVolumePosition *pos)
    Int_t puxmax = gPad->XtoAbsPixel(gPad->GetUxmax());
    Int_t puymax = gPad->YtoAbsPixel(gPad->GetUymax());
 
-//*-*- return if point is not in the user area
+///- return if point is not in the user area
    if (px < puxmin - inaxis) return big;
    if (py > puymin + inaxis) return big;
    if (px > puxmax + inaxis) return big;
@@ -393,7 +378,7 @@ Int_t TVolume::DistancetoNodePrimitive(Int_t px, Int_t py,TVolumePosition *pos)
       TShape  *shape = 0;
       TIter nextShape(fListOfShapes);
       while ((shape = (TShape *)nextShape())) {
-         //*-*- Distnance to the next referenced shape  if visible
+         ///- Distance to the next referenced shape  if visible
          if (shape->GetVisibility()) {
             Int_t dshape = shape->DistancetoPrimitive(px,py);
             if (dshape < maxdist) {
@@ -407,7 +392,7 @@ Int_t TVolume::DistancetoNodePrimitive(Int_t px, Int_t py,TVolumePosition *pos)
 
    if ( (GetVisibility() & kSonUnvisible) ) return dist;
 
-//*-*- Loop on all sons
+///- Loop on all sons
    TList *posList = GetListOfPositions();
    Int_t dnode = dist;
    if (posList && posList->GetSize()) {
@@ -434,14 +419,13 @@ Int_t TVolume::DistancetoNodePrimitive(Int_t px, Int_t py,TVolumePosition *pos)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-///*-*-*-*-*-*-*-*-*-*-*-*Draw Referenced node with current parameters*-*-*-*
-///*-*                   =============================================
+//// Draw Referenced node with current parameters
 
 void TVolume::Draw(Option_t *option)
 {
    TString opt = option;
    opt.ToLower();
-//*-*- Clear pad if option "same" not given
+///- Clear pad if option "same" not given
    if (!gPad) {
       gROOT->MakeDefCanvas();
    }
@@ -484,8 +468,7 @@ void TVolume::Draw(Option_t *option)
 
 
 ////////////////////////////////////////////////////////////////////////////////
-///*-*-*-*-*-*-*-*-*-*Draw only Sons of this node*-*-*-*-*-*-*-*-*-*-*-*-*
-///*-*                ===========================
+//// Draw only Sons of this node
 
 void TVolume::DrawOnly(Option_t *option)
 {
@@ -495,11 +478,10 @@ void TVolume::DrawOnly(Option_t *option)
 
 
 ////////////////////////////////////////////////////////////////////////////////
-///*-*-*-*-*-*-*-*-*-*-*Execute action corresponding to one event*-*-*-*
-///*-*                  =========================================
-///*-*  This member function must be implemented to realize the action
-///*-*  corresponding to the mouse click on the object in the window
-///*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
+//// Execute action corresponding to one event
+////
+////  This member function must be implemented to realize the action
+////  corresponding to the mouse click on the object in the window
 
 void TVolume::ExecuteEvent(Int_t, Int_t, Int_t)
 {
@@ -535,7 +517,7 @@ TRotMatrix *TVolume::GetIdentity()
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-///to be documented
+/// to be documented
 
 char *TVolume::GetObjectInfo(Int_t px, Int_t py) const
 {
@@ -558,8 +540,7 @@ char *TVolume::GetObjectInfo(Int_t px, Int_t py) const
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-///*-*-*-*-*-*-*Copy shape attributes as node attributes*-*-*-*-*--*-*-*-*-*-*
-///*-*          ========================================
+//// Copy shape attributes as node attributes
 
 void TVolume::ImportShapeAttributes()
 {
@@ -579,7 +560,7 @@ void TVolume::ImportShapeAttributes()
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-///*-*- Draw Referenced node
+////- Draw Referenced node
 
 void TVolume::Paint(Option_t *opt)
 {
@@ -590,15 +571,13 @@ void TVolume::Paint(Option_t *opt)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-///*-*-*-*-*-*-*-*-*-*-*-*Paint Referenced volume with current parameters*-*-*-*
-///*-*                   ==============================================
-///*-*
-///*-*  vis = 1  (default) shape is drawn
-///*-*  vis = 0  shape is not drawn but its sons may be not drawn
-///*-*  vis = -1 shape is not drawn. Its sons are not drawn
-///*-*  vis = -2 shape is drawn. Its sons are not drawn
-///*-*
-///*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
+//// Paint Referenced volume with current parameters
+////
+////
+////  vis = 1  (default) shape is drawn
+////  vis = 0  shape is not drawn but its sons may be not drawn
+////  vis = -1 shape is not drawn. Its sons are not drawn
+////  vis = -2 shape is drawn. Its sons are not drawn
 
 void TVolume::PaintNodePosition(Option_t *option,TVolumePosition *pos)
 {
@@ -620,7 +599,7 @@ void TVolume::PaintNodePosition(Option_t *option,TVolumePosition *pos)
    TVolumePosition *position = pos;
    if (!position)   position   = &nullPosition;
 
-   // PaintPosition does change the current matrix and it MUST be callled FIRST !!!
+   // PaintPosition does change the current matrix and it MUST be called FIRST !!!
 
    position->UpdatePosition(option);
 
@@ -628,7 +607,7 @@ void TVolume::PaintNodePosition(Option_t *option,TVolumePosition *pos)
 
    if (GetVisibility() & kSonUnvisible) return;
 
-//*-*- Paint all sons
+///- Paint all sons
    TList *posList = GetListOfPositions();
    if (posList && posList->GetSize()) {
       gGeometry->PushLevel();
@@ -734,15 +713,14 @@ void TVolume::DeletePosition(TVolumePosition *position)
 ///  Calculates the size of 3 box the volume occupies,
 ///  Return:
 ///    two floating point arrays with the bound of box
-///     surroundind all shapes of this TVolumeView
-///
+///     surrounding all shapes of this TVolumeView
 
 void TVolume::GetLocalRange(Float_t *min, Float_t *max)
 {
    TVirtualPad *savePad = gPad;
    //  Create a dummy TPad;
    TCanvas dummyPad("--Dumm--","dum",1,1);
-   // Assing 3D TView
+   // Asking 3D TView
    TView *view = TView::CreateView(1,0,0);
 
    gGeometry->SetGeomLevel();
@@ -756,14 +734,12 @@ void TVolume::GetLocalRange(Float_t *min, Float_t *max)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-///*-*-*-*-*-*-*Set visibility for this volume and its sons*-*-*-*-*--*-*-*-*-*-*
-///*-*          =========================================
+//// Set visibility for this volume and its sons
+///
 /// ENodeSEEN Visibility flag  00 - everything visible,
-///                            10 - this unvisible, but sons are visible
+///                            10 - this invisible, but sons are visible
 ///                            01 - this visible but sons
 ///                            11 - neither this nor its sons are visible
-///*-*
-///*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
 
 void TVolume::SetVisibility(ENodeSEEN vis)
 {
@@ -771,8 +747,7 @@ void TVolume::SetVisibility(ENodeSEEN vis)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-///*-*-*-*-*-*-*Return total size of this 3-D volume with its attributes*-*-*
-///*-*          ==========================================================
+//// *Return total size of this 3-D volume with its attributes
 
 void TVolume::Sizeof3D() const
 {
diff --git a/math/mathcore/inc/Math/ProbFuncMathCore.h b/math/mathcore/inc/Math/ProbFuncMathCore.h
index 2ce4c5a17c2281c643956920046eb23db57bd56e..b1e2bf6bc16ea9b902170b058ddc49d4ea33aad5 100644
--- a/math/mathcore/inc/Math/ProbFuncMathCore.h
+++ b/math/mathcore/inc/Math/ProbFuncMathCore.h
@@ -54,7 +54,7 @@ namespace Math {
    * their usage is deprecated.
    *
    *  These functions are defined in the header file <em>Math/ProbFunc.h<em> or in the global one
    *  including all statistical dunctions <em>Math/DistFunc.h<em>
    *
    */
 
@@ -203,45 +203,45 @@ namespace Math {
    /**
 
       Cumulative distribution for the Crystal Ball distribution function
-      
-      See the definition of the Crystal Ball function at 
+
+      See the definition of the Crystal Ball function at
       <A HREF="http://en.wikipedia.org/wiki/Crystal_Ball_function">
       Wikipedia</A>.
-      
-      The distribution is defined only for n > 1 when the integral converges 
+
+      The distribution is defined only for n > 1 when the integral converges
 
       @ingroup ProbFunc
 
-   */   
+   */
    double crystalball_cdf(double x, double alpha, double n, double sigma, double x0 = 0);
-   
+
    /**
 
       Complement of the Cumulative distribution for the Crystal Ball distribution
-      
-      See the definition of the Crystal Ball function at 
+
+      See the definition of the Crystal Ball function at
       <A HREF="http://en.wikipedia.org/wiki/Crystal_Ball_function">
       Wikipedia</A>.
-      
-      The distribution is defined only for n > 1 when the integral converges 
+
+      The distribution is defined only for n > 1 when the integral converges
 
       @ingroup ProbFunc
 
-   */   
+   */
    double crystalball_cdf_c(double x, double alpha, double n, double sigma, double x0 = 0);
-   
+
    /**
       Integral of the not-normalized Crystal Ball function
-      
-      See the definition of the Crystal Ball function at 
+
+      See the definition of the Crystal Ball function at
       <A HREF="http://en.wikipedia.org/wiki/Crystal_Ball_function">
       Wikipedia</A>.
-      
-      see ROOT::Math::crystalball_function for the function evaluation. 
+
+      see ROOT::Math::crystalball_function for the function evaluation.
 
       @ingroup ProbFunc
 
-   */   
+   */
    double crystalball_integral(double x, double alpha, double n, double sigma, double x0 = 0);
 
    /**
@@ -381,7 +381,7 @@ namespace Math {
    <A HREF="http://dx.doi.org/10.1016/0010-4655(84)90085-7">Computer Phys. Comm. 31 (1984) 97-111</A>
    <A HREF="http://dx.doi.org/10.1016/j.cpc.2008.03.002">[Erratum-ibid. 178 (2008) 972]</A>.
    The same algorithms as in
-   <A HREF="http://wwwasdoc.web.cern.ch/wwwasdoc/shortwrupsdir/g110/top.html">
+   <A HREF="https://cern-tex.web.cern.ch/cern-tex/shortwrupsdir/g110/top.html">
    CERNLIB</A> (DISLAN) is used.
 
    @param x The argument \f$x\f$
@@ -740,7 +740,7 @@ namespace Math {
    In the case of the Landau, first and second momentum functions are provided for the Landau
    distribution truncated only on the right side.
    These functions are defined in the header file <em>Math/ProbFunc.h<em> or in the global one
-   including all statistical dunctions <em>Math/StatFunc.h<em>
+   including all statistical functions <em>Math/StatFunc.h<em>
 
    */
 
@@ -756,7 +756,7 @@ namespace Math {
    <A HREF="http://dx.doi.org/10.1016/0010-4655(84)90085-7">Computer Phys. Comm. 31 (1984) 97-111</A>
    <A HREF="http://dx.doi.org/10.1016/j.cpc.2008.03.002">[Erratum-ibid. 178 (2008) 972]</A>.
    The same algorithms as in
-   <A HREF="http://wwwasdoc.web.cern.ch/wwwasdoc/shortwrupsdir/g110/top.html">
+   <A HREF="https://cern-tex.web.cern.ch/cern-tex/shortwrupsdir/g110/top.html">
    CERNLIB</A> (XM1LAN)  is used
 
    @param x The argument \f$x\f$
@@ -783,7 +783,7 @@ namespace Math {
    <A HREF="http://dx.doi.org/10.1016/0010-4655(84)90085-7">Computer Phys. Comm. 31 (1984) 97-111</A>
    <A HREF="http://dx.doi.org/10.1016/j.cpc.2008.03.002">[Erratum-ibid. 178 (2008) 972]</A>.
    The same algorithms as in
-   <A HREF="http://wwwasdoc.web.cern.ch/wwwasdoc/shortwrupsdir/g110/top.html">
+   <A HREF="https://cern-tex.web.cern.ch/cern-tex/shortwrupsdir/g110/top.html">
    CERNLIB</A> (XM1LAN)  is used
 
    @param x The argument \f$x\f$
@@ -54,7 +54,7 @@ namespace Math {
    *
    *  These functions are defined in the header file <em>Math/ProbFunc.h<em> or in the global one
-   *  including all statistical dunctions <em>Math/DistFunc.h<em>
+   *  including all statistical functions <em>Math/DistFunc.h<em>
    *
    */